﻿/**********************************************************************
 * CSHARP2008 USBisoExample .NET 2.0 or higher required
 * 04/05/2010
 * This example is only to demonstrate the functions required to 
 * query the USBisoVm board values with the help of USBisoVM_DLL.dll. 
 * This code is intended only for example purposes and contains limited
 * error handing.
 * You may use this code in your own project.
 * ********************************************************************/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Runtime.InteropServices;


namespace CSHARP2010_USBrelayExample
{
    public partial class Form1 : Form
    {
        //import the dll and define the function calls
        [DllImport("USBrelay_DLL.dll", CharSet = CharSet.Auto)]
        private static extern int TestDLL(byte[] buffer);

        [DllImport("USBrelay_DLL.dll", CharSet = CharSet.Auto)]
        private static extern int FindUSBrelayBoards(byte[] buffer);

        [DllImport("USBrelay_DLL.dll", CharSet = CharSet.Auto)]
        private static extern int GetManufacturerString(int ID, byte[] buffer);

        [DllImport("USBrelay_DLL.dll", CharSet = CharSet.Auto)]
        private static extern int GetProductString(int ID, byte[] buffer);

        [DllImport("USBrelay_DLL.dll", CharSet = CharSet.Auto)]
        private static extern int GetVersionString(int ID, byte[] buffer);

        [DllImport("USBrelay_DLL.dll", CharSet = CharSet.Auto)]
        private static extern int ReadUSBrelays(int ID, byte[] buffer);

        [DllImport("USBrelay_DLL.dll", CharSet = CharSet.Auto)]
        private static extern int WriteUSBrelay(int ID, int COMMAND, int LEDS);

        //Make a 1024 byte buffer that gets filled by the USBisoVM_DLL.dll
        private Encoding Encoding = System.Text.Encoding.ASCII;
        //Global variable that holds the first usb isolated voltmeter board found
        private string USBrelayFound = string.Empty;  
        //Global variable that holds the USB Relay Board ID
        private int ID;
        
        public Form1()
        {
            InitializeComponent();
            textBox1.Text = "(C)opyright 2011 EtherTek Circuits";
            textBox1.AppendText("\r\n");
        }

        private void button1_Click(object sender, EventArgs e)
        {
            //Call test dll function
            byte[] buffer = new byte[1024];
            int errnum = TestDLL(buffer);
            textBox1.AppendText(Encoding.GetString(buffer));
            textBox1.AppendText("\r\n");
        }

        private void button2_Click(object sender, EventArgs e)
        {
            //Find any connected USB Relay boards. This example will only display the first one found.
            byte[] buffer = new byte[1024];
            int errnum = FindUSBrelayBoards(buffer);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR No USB Relay boards found!\r\n");
                return;
            }

            USBrelayFound = Encoding.GetString(buffer, 0, 4);
            textBox1.AppendText(USBrelayFound);
            textBox1.AppendText("\r\n");

            //enable buttons
            button3.Enabled = true;
            button4.Enabled = true;
            button5.Enabled = true;
            button6.Enabled = true;
            button7.Enabled = true;
            button8.Enabled = true;
            button9.Enabled = true;
            button10.Enabled = true;
            button11.Enabled = true;
            button12.Enabled = true;
            button13.Enabled = true;
            button14.Enabled = true;
            button15.Enabled = true;
            checkBox1.Enabled = true;
            checkBox2.Enabled = true;
            checkBox3.Enabled = true;
            checkBox4.Enabled = true;
            checkBox5.Enabled = true;
            checkBox6.Enabled = true;
            button17.Enabled = true;

            ID = Convert.ToInt32(USBrelayFound, 16);

            byte[] firmware = new byte[8];
            int errnum1 = ReadUSBrelays(ID, buffer);
            if (errnum1 == 0)
            {
                textBox1.AppendText("Send ReadUSBrelays Failed!\r\n");
                return;
            }
            button2.Enabled = false;


            byte leds = buffer[6];
            int ans = leds & 1; 
            if (ans == 1)
            {
                checkBox1.Checked = true;
            }
            else
            {
                checkBox1.Checked = false;
            }

            ans = leds & 2;
            if (ans == 2)
            {
                checkBox2.Checked = true;
            }
            else
            {
                checkBox2.Checked = false;
            }

            ans = leds & 4;
            if (ans == 4)
            {
                checkBox3.Checked = true;
            }
            else
            {
                checkBox3.Checked = false;
            }

            ans = leds & 8;
            if (ans == 8)
            {
                checkBox4.Checked = true;
            }
            else
            {
                checkBox4.Checked = false;
            }

            ans = leds & 16;
            if (ans == 16)
            {
                checkBox5.Checked = true;
            }
            else
            {
                checkBox5.Checked = false;
            }

            ans = leds & 32;
            if (ans == 32)
            {
                checkBox6.Checked = true;
            }
            else
            {
                checkBox6.Checked = false;
            }

            firmware[0] = buffer[7];
            firmware[1] = buffer[8];
            firmware[2] = buffer[9];
            firmware[3] = buffer[10];
            firmware[4] = 0;
            textBox2.Text=(Encoding.GetString(firmware, 0, 4).Replace("\0", ""));

        }

        private void button3_Click(object sender, EventArgs e)
        {
            //call the GetManufacturerString function.
            //Returns the Manufacturer String unless there is an error.
            byte[] buffer = new byte[1024];
            int errnum = GetManufacturerString(ID, buffer);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            Encoding.GetString(buffer, 0, 32).Replace("\0", "");
            textBox1.AppendText(Encoding.GetString(buffer, 0, 32).Replace("\0", ""));
            textBox1.AppendText("\r\n");
        }


        private void button4_Click(object sender, EventArgs e)
        {
            //call the GetProductString function.
            //Returns the Product String unless there is an error.
            byte[] buffer = new byte[1024];
            int errnum = GetProductString(ID, buffer);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            Encoding.GetString(buffer, 0, 32).Replace("\0", "");
            textBox1.AppendText(Encoding.GetString(buffer).Replace("\0", ""));
            textBox1.AppendText("\r\n");
        }

        private void button5_Click(object sender, EventArgs e)
        {
            //call the GetVersionString function.
            //Returns the Version String unless there is an error.
            byte[] buffer = new byte[1024];
            int errnum = GetVersionString(ID, buffer);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            Encoding.GetString(buffer, 0, 32).Replace("\0", "");
            textBox1.AppendText(Encoding.GetString(buffer).Replace("\0", ""));
            textBox1.AppendText("\r\n");
        }

        private void button6_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //Energizes Relay 1 unless there is an error.
            int errnum = WriteUSBrelay(ID, 1,0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 1 ON\r\n");
        }

        private void button7_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //De-Energizes Relay 1 unless there is an error.
            int errnum = WriteUSBrelay(ID, 0, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 1 OFF\r\n");
        }

        private void button8_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //Energizes Relay 2 unless there is an error.
            int errnum = WriteUSBrelay(ID, 3, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 2 ON\r\n");
        }

        private void button9_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //De-Energizes Relay 2 unless there is an error.
            int errnum = WriteUSBrelay(ID, 2, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 2 OFF\r\n");
        }

        private void button10_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //Energizes Relay 3 unless there is an error.
            int errnum = WriteUSBrelay(ID, 5, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 3 ON\r\n");
        }

        private void button11_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //De-Energizes Relay 3 unless there is an error.
            int errnum = WriteUSBrelay(ID, 4, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 3 OFF\r\n");
        }

        private void button12_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //Energizes Relay 4 unless there is an error.
            int errnum = WriteUSBrelay(ID, 7, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 4 ON\r\n");
        }

        private void button13_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //De-Energizes Relay 4 unless there is an error.
            int errnum = WriteUSBrelay(ID, 6, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 4 OFF\r\n");
        }

        private void button14_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //Energizes Relay 5 unless there is an error.
            int errnum = WriteUSBrelay(ID, 9, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 5 ON\r\n");
        }

        private void button15_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //De-Energizes Relay 5 unless there is an error.
            int errnum = WriteUSBrelay(ID, 8, 0);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("Relay 5 OFF\r\n");
        }

        private void button16_Click(object sender, EventArgs e)
        {
            MessageBox.Show("USB Relay Board C# example (C)2011 EtherTek Circuits");
        }

        private void button17_Click(object sender, EventArgs e)
        {
            //call the WriteUSBrelay function.
            //Sends LED info unless there is an error.

            int led = 0;

            if (checkBox1.Checked == true)
            {

                led = led | 1;
            }

            if (checkBox2.Checked == true)
            {

                led = led | 2;
            }

            if (checkBox3.Checked == true)
            {

                led = led | 4;
            }

            if (checkBox4.Checked == true)
            {

                led = led | 8;
            }

            if (checkBox5.Checked == true)
            {

                led = led | 16;
            }

            if (checkBox6.Checked == true)
            {

                led = led | 32;
            }
            
            int errnum = WriteUSBrelay(ID, 11, led);

            if (errnum == 0)
            {
                textBox1.AppendText("ERROR Function Call Failed\r\n");
                return;
            }

            textBox1.AppendText("LED info sent\r\n");
        }

        private void button18_Click(object sender, EventArgs e)
        {
            Environment.Exit(0);
        }

        

        

        

        

        

        
    }
}
